import{_ as B}from"./logo.084e5d7c.js";import{v as C,b as r,er as y,eB as I,eC as w,e as h,d as k,ex as L,a as N,u as e,c,bP as S,w as t,f as o,b0 as d,eA as _,cb as m,cN as D,q as V,ez as P,eX as R,bu as T,eu as U}from"./registerWidgets.1e9167ab.js";import{p as b}from"./passwordlessManager.b7f590c1.js";import{a as E}from"./asyncComputed.8a644895.js";import{A as $}from"./Text.c8d7b4c0.js";import{A as g}from"./index.d74062f4.js";import{A as j,B as q,a as z,c as F}from"./index.4b30ebdc.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[s]="afd8f425-7ad1-41b9-a8b8-567df9c46f81",a._sentryDebugIdIdentifier="sentry-dbid-afd8f425-7ad1-41b9-a8b8-567df9c46f81")}catch{}})();const H={},v=a=>(I("data-v-439be421"),a=a(),w(),a),M={class:"logo"},X=v(()=>h("img",{class:"logo-img",src:B,alt:"Abstra cloud logo"},null,-1)),G=v(()=>h("span",null,"Abstra Cloud",-1)),J=[X,G];function K(a,s){return r(),y("div",M,J)}const O=C(H,[["render",K],["__scopeId","data-v-439be421"]]),Q=k({__name:"LoginBlock",setup(a){function s(p){const f=p.split("@")[0];return V.exports.kebabCase(f).toUpperCase().split("-").slice(0,2).map(i=>i[0]).join("")}const l=L(),{result:n,loading:u,refetch:x}=E(async()=>b.getUser());function A(){b.removeUser(),x(),l.push({name:"login"})}return(p,f)=>{const i=N("router-link");return e(u)?(r(),c(e(S),{key:0})):e(n)?(r(),c(e(D),{key:1,placement:"bottomRight"},{content:t(()=>[o(e(g),{direction:"vertical"},{default:t(()=>[o(e($),null,{default:t(()=>[d(_(e(n).claims.email),1)]),_:1}),o(e(m),{onClick:A},{default:t(()=>[d("Logout")]),_:1})]),_:1})]),default:t(()=>[o(e(g),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[o(e(j),null,{default:t(()=>[d(_(s(e(n).claims.email)),1)]),_:1})]),_:1})]),_:1})):(r(),c(e(m),{key:2},{default:t(()=>[o(i,{to:"/login"},{default:t(()=>[d("Login")]),_:1})]),_:1}))}}}),se=k({__name:"Navbar",props:{breadcrumb:{}},setup(a){return(s,l)=>(r(),c(e(F),{style:{padding:"5px 10px"}},{breadcrumb:t(()=>[s.breadcrumb?(r(),c(e(q),{key:0},{default:t(()=>[(r(!0),y(T,null,P(s.breadcrumb,(n,u)=>(r(),c(e(z),{key:u},{default:t(()=>[o(e(R),{to:n.path},{default:t(()=>[d(_(n.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):U("",!0)]),title:t(()=>[o(O)]),extra:t(()=>[o(Q)]),_:1}))}});export{se as _};
//# sourceMappingURL=Navbar.vue_vue_type_script_setup_true_lang.901e5473.js.map
